/* This provides a fairly generic main routine for terminal-based stk projects.
It expects to have stuff added to it, otherwise it will just generate lots of silence. 
This is derived from 220 class assignments 1 & 2, and provides choices for audio plumbing.
The first thing you should change is this comment. 
One last thing: if you're not using ADAC or WVIN there is no harm in deleting all of the corresponding
#if's, etc. lines to make it easier to read. */

// select real-time DAC, real-time mic (ADAC), wavefile input, and / or wavefile output
#define DAC TRUE		// if FALSE, then only write wave file
#define ADAC FALSE		// if FALSE, then run in "DAC" mode with no mic input
#define WVIN FALSE		// if TRUE, a valid wave filename needs to be set in the WvIn constructor
#define WVOUT TRUE		// wavefile out, defaults to "/zap/test.wav"
// pick your audio resolution
#define NCHANS 2
#define SRATE_HZ 48000
#define END_SECS 1.0		// ends the performance

#include "RtDuplex.h"
#include "RtWvOut.h"
#include "WvIn.h"
#include "WvOut.h"
 
int
main (void)
{
	Stk::setSampleRate (SRATE_HZ);
#if ADAC
	RtDuplex *rt = new RtDuplex (NCHANS);
#elif DAC
	RtWvOut *rt = new RtWvOut (NCHANS);
#endif
#if WVIN
	WvIn *inFile = new WvIn ("/zap/kern.wav");	// specify a real filename
#endif
#if WVOUT
	WvOut *outFile = new WvOut ("/zap/test.wav", NCHANS);
#endif
	int end = (int) (END_SECS * SRATE_HZ);
	double outFrame[NCHANS];
	int i;
	for (i = 0; i < NCHANS; i++)
		outFrame[i] = 0.0;
#if ADAC
	double *inFrame = NULL;
#endif
#if WVIN
	double *inFileFrame = NULL;
#endif
	/* ------ this is where the real work happens ------ */
	for (int frameCounter = 0; frameCounter < end; frameCounter++)
	{
		// get incoming frames, if any
#if WVIN
		inFileFrame = (double *) inFile->tickFrame ();
#endif
		// put code here that will produce more interesting output than these zeroes

		for (i = 0; i < NCHANS; i++)
			outFrame[i] = 0.0;

		// send output
#if ADAC
		inFrame = (double *) rt->tickFrame (outFrame);
#elif DAC
		rt->tickFrame (outFrame);
#endif
#if WVOUT
		outFile->tickFrame (outFrame);
#endif
	}
	/* ------------------------------------------------ */

#if WVIN
	delete inFile;
#endif
#if (ADAC || DAC)
	delete rt;
#endif
#if WVOUT
	delete outFile;
#endif
}


